## _publications_

The _publications_ servive provides API functionality for accessing the
Progenetix [publications](http://progenetix.org/publications/) collection, which
represents curated information about several thousand articles reporting
genome-wide screening experiments in cancer. 

#### Examples

* <https://progenetix.org/services/publications/?filters=PMID>
* <http://progenetix.org/services/publications/?filters=PMID,genomes:&gt;200,arraymap:&gt;1>
* <http://progenetix.org/services/publications/?filters=PMID:22824167&method=details>
* <http://progenetix.org/services/publications/?geoLongitude=8.55&geoLatitude=47.37&geoDistance=100000>

